agentVersion top-level constant
String
const agentVersion
Flutter Agent version This should match the version in pubspec.yaml
Implementation
const String agentVersion = '1.3.1';
Flutter Agent version This should match the version in pubspec.yaml
const String agentVersion = '1.3.1';